@@ -1,21 +1,8 @@
-/***********************************************************************
- *
- * Copyright (C) 2010, 2011, 2012, 2014, 2015, 2017 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2010-2021 Graeme Gott <graeme@gottcode.org>
+
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "new_game_dialog.h"
 
@@ -35,47 +22,9 @@
 
 //-----------------------------------------------------------------------------
 
-namespace
-{
-	class TimerDescription
-	{
-	public:
-		TimerDescription(int id)
-			: m_name(Clock::timerToString(id)), m_description(Clock::timerDescription(id)), m_id(id)
-		{
-		}
-
-		QString name() const
-		{
-			return m_name;
-		}
-
-		QString description() const
-		{
-			return m_description;
-		}
-
-		int id() const
-		{
-			return m_id;
-		}
-
-		bool operator<(const TimerDescription& timer) const
-		{
-			return m_name.localeAwareCompare(timer.m_name) < 0;
-		}
-
-	private:
-		QString m_name;
-		QString m_description;
-		int m_id;
-	};
-}
-
-//-----------------------------------------------------------------------------
-
 NewGameDialog::NewGameDialog(QWidget* parent)
-	: QDialog(parent, Qt::WindowTitleHint | Qt::WindowSystemMenuHint | Qt::WindowCloseButtonHint), m_minimum(3)
+	: QDialog(parent, Qt::WindowTitleHint | Qt::WindowSystemMenuHint | Qt::WindowCloseButtonHint)
+	, m_minimum(3)
 {
 	setWindowTitle(tr("New Game"));
 
@@ -131,7 +80,7 @@ NewGameDialog::NewGameDialog(QWidget* parent)
 	for (int i = 0; i < 4; ++i) {
 		m_length->addItem("");
 	}
-	connect(m_length, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &NewGameDialog::lengthChanged);
+	connect(m_length, qOverload<int>(&QComboBox::currentIndexChanged), this, &NewGameDialog::lengthChanged);
 	m_minimum = settings.value("Board/Minimum", 3).toInt();
 	if (m_large_size->isChecked()) {
 		--m_minimum;
@@ -148,27 +97,33 @@ NewGameDialog::NewGameDialog(QWidget* parent)
 	layout->addSpacing(6);
 
 	// Create timer buttons
-	QScrollArea* area = new QScrollArea(this);
-	layout->addWidget(area);
+	m_timers_area = new QScrollArea(this);
+	layout->addWidget(m_timers_area);
 
-	QWidget* timers_widget = new QWidget(area);
+	QWidget* timers_widget = new QWidget(m_timers_area);
 	QVBoxLayout* timers_layout = new QVBoxLayout(timers_widget);
-	area->setWidget(timers_widget);
-	area->setWidgetResizable(true);
+	m_timers_area->setWidget(timers_widget);
+	m_timers_area->setWidgetResizable(true);
+	m_timers_area->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 
-	QCommandLinkButton* active_timer = 0;
-	QList<TimerDescription> timers;
-	for (int i = Clock::Tanglet; i < Clock::TotalTimers; ++i) {
-		timers.append(i);
-	}
-	std::sort(timers.begin(), timers.end());
-	for (const TimerDescription& timer : timers) {
-		QCommandLinkButton* button = new QCommandLinkButton(timer.name(), timer.description(), timers_widget);
+	QCommandLinkButton* active_timer = nullptr;
+	for (int timer = 0; timer < Clock::TotalTimers; ++timer) {
+		const QString name = Clock::timerToString(timer);
+
+		QCommandLinkButton* button = new QCommandLinkButton(name, Clock::timerDescription(timer), timers_widget);
 		button->setMinimumWidth(500);
-		connect(button, &QCommandLinkButton::clicked, [=] { timerChosen(timer.id()); });
-		timers_layout->addWidget(button);
+		connect(button, &QCommandLinkButton::clicked, this, [this, timer] { timerChosen(timer); });
 
-		if (timer.id() == previous_timer) {
+		int i;
+		for (i = 0; i < m_timers.size(); ++i) {
+			if (m_timers[i]->text().localeAwareCompare(name) >= 0) {
+				break;
+			}
+		}
+		m_timers.insert(i, button);
+		timers_layout->insertWidget(i, button);
+
+		if (timer == previous_timer) {
 			button->setDefault(true);
 			button->setFocus();
 			active_timer = button;
@@ -176,28 +131,34 @@ NewGameDialog::NewGameDialog(QWidget* parent)
 	}
 
 	// Create cancel button
-	QDialogButtonBox* buttons = new QDialogButtonBox(QDialogButtonBox::Cancel, Qt::Horizontal, this);
-	connect(buttons, &QDialogButtonBox::rejected, this, &NewGameDialog::reject);
+	m_buttons = new QDialogButtonBox(QDialogButtonBox::Cancel | QDialogButtonBox::RestoreDefaults, Qt::Horizontal, this);
+	connect(m_buttons, &QDialogButtonBox::rejected, this, &NewGameDialog::reject);
+	connect(m_buttons, &QDialogButtonBox::clicked, this, &NewGameDialog::restoreDefaults);
 	layout->addSpacing(6);
-	layout->addWidget(buttons);
+	layout->addWidget(m_buttons);
 
 	// Show contents
-	QSize size = sizeHint() + QSize(area->verticalScrollBar()->sizeHint().width(), area->frameWidth() * 2);
+	m_timers_area->setMinimumWidth(timers_widget->sizeHint().width()
+			+ m_timers_area->verticalScrollBar()->sizeHint().width()
+			+ (m_timers_area->frameWidth() * 2));
+	QSize size = sizeHint();
+	size.setHeight(size.height() - (m_timers_area->sizeHint().height() / 3));
 	resize(QSettings().value("NewGameDialog/Size", size).toSize());
 	show();
 	if (active_timer) {
-		area->ensureWidgetVisible(active_timer);
+		m_timers_area->ensureWidgetVisible(active_timer);
 	}
 }
 
 //-----------------------------------------------------------------------------
 
-QString NewGameDialog::densityString(int density) {
+QString NewGameDialog::densityString(int density)
+{
 	static QStringList densities = QStringList()
-		<< tr("Low")
-		<< tr("Medium")
-		<< tr("High")
-		<< tr("Random");
+			<< tr("Low")
+			<< tr("Medium")
+			<< tr("High")
+			<< tr("Random");
 	return densities.at(qBound(0, density, densities.count() - 1));
 }
 
@@ -237,3 +198,31 @@ void NewGameDialog::timerChosen(int timer)
 }
 
 //-----------------------------------------------------------------------------
+
+void NewGameDialog::restoreDefaults(QAbstractButton* button)
+{
+	if (m_buttons->buttonRole(button) != QDialogButtonBox::ResetRole) {
+		return;
+	}
+
+	m_normal_size->setChecked(true);
+	m_density->setCurrentIndex(1);
+	sizeChanged();
+	m_length->setCurrentIndex(0);
+
+	const QString name = Clock::timerToString(Clock::Tanglet);
+	QCommandLinkButton* timer = nullptr;
+	for (QCommandLinkButton* b : qAsConst(m_timers)) {
+		if (b->text() == name) {
+			timer = b;
+			break;
+		}
+	}
+	if (timer) {
+		timer->setDefault(true);
+		timer->setFocus();
+		m_timers_area->ensureWidgetVisible(timer);
+	}
+}
+
+//-----------------------------------------------------------------------------
