@@ -1,5 +1,5 @@
 /*
-	SPDX-FileCopyrightText: 2009-2022 Graeme Gott <graeme@gottcode.org>
+	SPDX-FileCopyrightText: 2009-2023 Graeme Gott <graeme@gottcode.org>
 
 	SPDX-License-Identifier: GPL-3.0-or-later
 */
@@ -39,6 +39,10 @@
 
 //-----------------------------------------------------------------------------
 
+QString Window::m_data_path;
+
+//-----------------------------------------------------------------------------
+
 /**
  * @brief The Window::State class controls which central widget is shown in the main window.
  */
@@ -495,10 +499,14 @@ Window::Window(const QString& file)
 
 	// Create game menu
 	QMenu* menu = menuBar()->addMenu(tr("&Game"));
-	menu->addAction(tr("New &Game..."), this, &Window::newGame, tr("Ctrl+Shift+N"));
-	menu->addAction(tr("&New Roll"), this, &Window::newRoll, QKeySequence::New);
-	menu->addAction(tr("&Choose..."), this, &Window::chooseGame, QKeySequence::Open);
-	menu->addAction(tr("&Share..."), this, &Window::shareGame, QKeySequence::Save);
+	QAction* action = menu->addAction(tr("New &Game..."), this, &Window::newGame);
+	action->setShortcut(tr("Ctrl+Shift+N"));
+	action = menu->addAction(tr("&New Roll"), this, &Window::newRoll);
+	action->setShortcut(QKeySequence::New);
+	action = menu->addAction(tr("&Choose..."), this, &Window::chooseGame);
+	action->setShortcut(QKeySequence::Open);
+	action = menu->addAction(tr("&Share..."), this, &Window::shareGame);
+	action->setShortcut(QKeySequence::Save);
 	menu->addSeparator();
 	QAction* end_action = menu->addAction(tr("&End"), this, &Window::endGame);
 	end_action->setEnabled(false);
@@ -512,9 +520,11 @@ Window::Window(const QString& file)
 	menu->addSeparator();
 	m_details_action = menu->addAction(tr("&Details"), this, &Window::showDetails);
 	m_details_action->setEnabled(false);
-	menu->addAction(tr("&High Scores"), this, &Window::showScores, tr("Ctrl+H"));
+	action = menu->addAction(tr("&High Scores"), this, &Window::showScores);
+	action->setShortcut(tr("Ctrl+H"));
 	menu->addSeparator();
-	QAction* action = menu->addAction(tr("&Quit"), this, &Window::close, tr("Ctrl+Q"));
+	action = menu->addAction(tr("&Quit"), this, &Window::close);
+	action->setShortcut(tr("Ctrl+Q"));
 	action->setMenuRole(QAction::QuitRole);
 	monitorVisibility(menu);
 
@@ -715,7 +725,7 @@ void Window::about()
 		QString("<center><p><big><b>%1</b></big><br/>%2<br/><small>%3<br/>%4</small></p><p>%5</p><p>%6</p></center>")
 		.arg(tr("Tanglet %1").arg(QCoreApplication::applicationVersion()),
 			tr("A single player variant of <a href=\"http://en.wikipedia.org/wiki/Boggle\">Boggle</a>"),
-			tr("Copyright &copy; 2009-%1 Graeme Gott").arg("2022"),
+			tr("Copyright &copy; 2009-%1 Graeme Gott").arg("2023"),
 			tr("Released under the <a href=\"http://www.gnu.org/licenses/gpl.html\">GPL 3</a> license"),
 			tr("English word list is based on <a href=\"http://wordlist.sourceforge.net/\">SCOWL</a> by Kevin Atkinson"),
 			tr("Hebrew word list is based on <a href=\"http://hspell.ivrix.org.il/\">Hspell</a> by Nadav Har'El and Dan Kenigsberg"))
@@ -956,7 +966,7 @@ void Window::gameFinished(int score, int max_score)
 		scores.exec();
 	}
 
-	QDir dir(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation));
+	QDir dir(m_data_path);
 	dir.remove("current");
 	dir.remove("current-dice");
 	dir.remove("current-words");
@@ -996,7 +1006,7 @@ void Window::startGame(const QString& filename)
 		}
 	} else {
 		// Uncompress requested game
-		QString current = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation);
+		QString current = m_data_path;
 		QDir::home().mkpath(current);
 		current += "/current";
 
