@@ -1,21 +1,8 @@
-/***********************************************************************
- *
- * Copyright (C) 2011, 2014, 2018 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2011-2018 Graeme Gott <graeme@gottcode.org>
+
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "word_counts.h"
 
@@ -28,7 +15,8 @@
 //-----------------------------------------------------------------------------
 
 WordCounts::WordCounts(QWidget* parent)
-	: QScrollArea(parent), m_show_max(false)
+	: QScrollArea(parent)
+	, m_show_max(false)
 {
 	setBackgroundRole(QPalette::Mid);
 	setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);
