@@ -7,10 +7,6 @@
         <source>Details</source>
         <translation>Szczegóły</translation>
     </message>
-    <message>
-        <source>Clear</source>
-        <translation>Wyczyść</translation>
-    </message>
     <message>
         <source>Guess</source>
         <translation>Zgadnij</translation>
@@ -178,6 +174,14 @@
         <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
         <translation>Odlicza 30 sekund i zwiększa lub zmniejsza przy prawidłowych próbach.</translation>
     </message>
+    <message>
+        <source>Unlimited</source>
+        <translation>Bez limitu</translation>
+    </message>
+    <message>
+        <source>Game ends when all words are found.</source>
+        <translation>Gra kończy się, gdy wszystkie słowa zostaną znalezione.</translation>
+    </message>
 </context>
 <context>
     <name>Generator</name>
@@ -298,32 +302,52 @@
         <translation>Najlepsze wyniki</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Name&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Imię&lt;/b&gt;</translation>
+        <source>Name</source>
+        <translation>Imię</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Score&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Wynik&lt;/b&gt;</translation>
+        <source>Score</source>
+        <translation>Wynik</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Date&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Data&lt;/b&gt;</translation>
-    </message>
-    <message>
-        <source>&lt;b&gt;Timer&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Czas&lt;/b&gt;</translation>
+        <source>Date</source>
+        <translation>Data</translation>
     </message>
     <message>
         <source>#%1</source>
         <translation>#%1</translation>
     </message>
     <message>
-        <source>Question</source>
-        <translation>Pytanie</translation>
+        <source>Rank</source>
+        <translation>Ranga</translation>
     </message>
     <message>
-        <source>Clear high scores?</source>
-        <translation>Czy wyczyść najlepsze wyniki?</translation>
+        <source>Maximum</source>
+        <translation>Maksimum</translation>
+    </message>
+    <message>
+        <source>Size</source>
+        <translation>Rozmiar</translation>
+    </message>
+    <message>
+        <source>Congratulations!</source>
+        <translation>Gratulacje!</translation>
+    </message>
+    <message>
+        <source>You beat your top score!</source>
+        <translation>Pobiłeś swój najlepszy wynik!</translation>
+    </message>
+    <message>
+        <source>Well done!</source>
+        <translation>Dobra robota!</translation>
+    </message>
+    <message>
+        <source>You have a new high score!</source>
+        <translation>Masz nowy najlepszy wynik!</translation>
+    </message>
+    <message>
+        <source>N/A</source>
+        <translation>brak</translation>
     </message>
 </context>
 <context>
@@ -452,18 +476,10 @@
         <source>&amp;About</source>
         <translation>&amp;O</translation>
     </message>
-    <message>
-        <source>About &amp;Hspell</source>
-        <translation>O &amp;Hspell</translation>
-    </message>
     <message>
         <source>About &amp;Qt</source>
         <translation>O &amp;Qt</translation>
     </message>
-    <message>
-        <source>About &amp;SCOWL</source>
-        <translation>O &amp;SCOWL</translation>
-    </message>
     <message>
         <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
         <translation>Prawo autorskie &amp;copy; 2009-%1 Graeme Gott</translation>
@@ -492,14 +508,6 @@
         <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
         <translation>Hebrajska lista słów oparta jest na &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; przez Nadava Har&apos;Ela i Dana Kenigsberga</translation>
     </message>
-    <message>
-        <source>About Hspell</source>
-        <translation>O Hspell</translation>
-    </message>
-    <message>
-        <source>About SCOWL</source>
-        <translation>O SCOWL</translation>
-    </message>
     <message>
         <source>Import Game</source>
         <translation>Importuj grę</translation>
@@ -572,6 +580,10 @@
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Sterowanie myszą:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Wybór słowa:&lt;/b&gt; Kliknij na literę słowa.&lt;br&gt;&lt;b&gt;Zgadnij:&lt;/b&gt; Kliknij na ostatniej wybranej literze.&lt;br&gt;&lt;b&gt;Usuń litery:&lt;/b&gt; Kliknij na wcześniej wybranej literze.&lt;br&gt;&lt;b&gt;Wyczyść słowo:&lt;/b&gt; Kliknij dwa razy na pierwszą wybraną literę.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Sterowanie klawiaturą:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Wybierz słowo:&lt;/b&gt; Wpisz litery słowa.&lt;br&gt;&lt;b&gt;Zgadnij:&lt;/b&gt; Naciśnij klawisz Enter.&lt;br&gt;&lt;b&gt;Wyczyść słowo:&lt;/b&gt; Naciśnij Ctrl+Backspace.&lt;/p&gt;</translation>
     </message>
+    <message>
+        <source>Ctrl+H</source>
+        <translation>Ctrl+H</translation>
+    </message>
 </context>
 <context>
     <name>WordCounts</name>
